#
# spec file for package python-rpyc
#
# Copyright (c) 2015 SUSE LINUX Products GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.
#
# Please submit bugfixes or comments via http://bugs.opensuse.org/
#

Name:           python3-rpyc
Version:        3.3.0
Release:        2.3
License:        MIT
Summary:        Remote Python Call (RPyC), a Transparent and Symmetric RPC Library
Url:            http://rpyc.readthedocs.org
Group:          Development/Libraries/Python
Source:         https://files.pythonhosted.org/packages/source/r/rpyc/rpyc-%{version}.tar.gz
BuildRequires:  python3-devel
BuildRoot:      %{_tmppath}/%{name}-%{version}-build
BuildArch:      noarch

%description
A symmetric library for transparent RPC, clustering and distributed computing
for python, built around the concept of remote services and object proxying.

%prep
%setup -q -n rpyc-%{version}

%build
python3 setup.py build

%install
python3 setup.py install --prefix=%{_prefix} --root=%{buildroot}
mv %{buildroot}%{_bindir}/rpyc_classic.py %{buildroot}%{_bindir}/rpyc_classic-python%{py3_ver}.py
mv %{buildroot}%{_bindir}/rpyc_registry.py %{buildroot}%{_bindir}/rpyc_registry-python%{py3_ver}.py

%files
%defattr(-,root,root)
%doc README.rst LICENSE
%{_bindir}/*
%{python3_sitelib}/*

%changelog
* Sun May  8 2016 arun@gmx.de
- specfile:
  * updated source url to files.pythonhosted.org
* Fri Jan  9 2015 arun@gmx.de
- specfile:
  * update copyright year
  * the specfile was used for both v2 and v3 of python, make it python3 only
  * remove if for opensuse version <1110
  * update url
  * update source url to pypi
- update to version 3.3.0:
  * RPyC integrates with plumbum; plumbum is required for some
    features, like rpyc_classic.py and zero deploy, but the core of
    the library does n’t require it. It is, of course, advised to have
    it installed.
  * SshContext, SshTunnel classes killed in favor of plumbum’s SSH
    tunneling. The interface doesn’t change much, except that
    ssh_connect now accept a plumbum.SshMachine instance instead of
    SshContext.
  * Zero deploy: deploy RPyC to a remote machine over an SSH
    connection and form an SSH tunnel connected to it, in just one
    line of code. All you need is SSH access and a Python interpreter
    installed on the remote machine.
  * Dropping Python 2.4 support. RPyC now requires Python 2.5 - 3.3.
  * rpycd - a well-behaved daemon for rpyc_classic.py, based on
    python-daemon
  * The OneShotServer is now exposed by rpyc_classic -m oneshot
  * scripts directory renamed bin
  * Introducing Splitbrain Python - running code on remote machines
    transparently. Although tested, it is still considered
    experimental.
  * Removing the BgServerThread and all polling/timeout hacks in favor
    of a “global background reactor thread” that handles all incoming
    transport from all connections. This should solve all threading
    issues once and for all.
  * Added MockClassicConnection - a mock RPyC “connection” that allows
    you to write code that runs either locally or remotely without
    modification
  * Added teleport_function
* Mon Jan 21 2013 p.drouand@gmail.com
- Initial python3 support
* Mon Jan 21 2013 p.drouand@gmail.com
- Update to version 3.2.3:
  * No changelog available
* Tue Mar 13 2012 jfunk@funktronics.ca
- Update to 3.2.1:
  * Adding missing import (#52)
  * Fixing site documentation issue (#54)
  * Fixing Python 3 incompatibilities (#58, #59, #60, #61, #66)
  * Fixing slice issue (#62)
  * Added the endpoints parameter to the config dict of connection (only on
    the server side)
* Thu Dec  8 2011 jfunk@funktronics.ca
- Update to 3.2.0
  - Added support for IPv6 (#28)
  - Added SSH tunneling support (ssh_connect)
  - Added restricted object wrapping
  - Several fixes to AsyncResult and weak references
  - Added the ThreadPoolServer
  - Fixed some minor (harmless) races that caused tracebacks occasionally when
    server-threads terminated
  - Fixes issues #8, #41, #42, #43, #46, and #49.
  - Converted all CRLF to LF (#40)
  - Dropped TLSlite integration (#45). We’ve been dragging this corpse for too
    long
  - New documentation (both the website and docstrings) written in Sphinx
  - Python 3.0-3.2 support
- 3.1.0
  - Supports CPython 2.4-2.7, IronPython, and Jython
  - tlslite has been ported to python 2.5-2.7 (the original library targeted
    2.3 and 2.4)
  - Initial python 3 support – not finished!
  - Moves to a more conventional directory structure
  - Moves to more standard facilities (logging, nosetests)
  - Solves a major performance issue with the BgServingThread (#32), by
    removing the contention between the two threads that share the connection
  - Fixes lots of issues concerning the ForkingServer (#3, #7, and #15)
  - Many small bug fixes (#16, #13, #4, etc.)
  - Integrates with the built-in ssl module for SSL support
  - rpyc_classic.py now takes several --ssl-xxx switches (see --help for more
    info)
  - Fixes typos, running pylint, etc.
  - Breakage from 3.0.7:
  - Removing egg builds (we’re pure python, and eggs just messed up the
    build)
  - Package layout changed drastically, and some files were renamed
  - The servers/ directory was renamed scripts/
  - classic_server.py was renamed rpyc_classic.py
  - They scripts now install to your python scripts directory (no longer
    part of the package), e.g. C:\python27\Scripts
  - rpyc_classic.py now takes --register in order to register, instead of
  - -dont-register, which was a silly choice
  - classic.tls_connect, factory.tls_connect were renamed tlslite_connect,
    to distinguish it from the new ssl_connect
* Thu Feb 18 2010 jfunk@funktronics.ca
- Update to 3.0.7
* Tue Jul 17 2007 James Oakley <jfunk@funktronics.ca> - 2.60-1
- Initial release
